==> tutti-ui-swing-2.2-sources.jar: fr/ifremer/tutti/ui/swing/content/referential/ExportTemporarySpeciesExampleAction.java <==
package fr.ifremer.tutti.ui.swing.content.referential;

/*
 * #%L
 * Tutti :: UI
 * $Id: ExportTemporarySpeciesExampleAction.java 845 2013-04-22 06:53:55Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.2/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/referential/ExportTemporarySpeciesExampleAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Preconditions;
import fr.ifremer.tutti.TuttiIOUtil;
import fr.ifremer.tutti.service.referential.TuttiReferentialImportExportService;
import fr.ifremer.tutti.ui.swing.TuttiUIContext;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.io.File;

import static org.nuiton.i18n.I18n._;

/**
 * Export an example file of temporary species referential.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ExportTemporarySpeciesExampleAction extends AbstractTuttiAction<TuttiUIContext, ManageTemporaryReferentialUI, ManageTemporaryReferentialUIHandler> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ExportTemporarySpeciesExampleAction.class);

    private File file;

    public ExportTemporarySpeciesExampleAction(ManageTemporaryReferentialUIHandler handler) {
        super(handler, true);
    }

    @Override
    protected boolean prepareAction() throws Exception {

        boolean doAction = super.prepareAction();

        if (doAction) {

            // choose file to export
            file = TuttiUIUtil.saveFile(
                    "exportSpeciesExample.csv",
                    getContext().getMainUI(),
                    _("tutti.manageTemporaryReferential.title.choose.exportTemporarySpeciesExampleFile"),
                    _("tutti.manageTemporaryReferential.action.chooseReferentialSpeciesFile"),
                    "^.*\\.csv", _("tutti.common.file.csv")
            );
            if (file == null) {

                // user cancel
                doAction = false;
            } else {

                // add extension if missing
                file = TuttiIOUtil.addExtensionIfMissing(file, ".csv");

                // ask user to confirm overwrite.
                doAction = getHandler().askOverwriteFile(file);
            }
        }
        return doAction;
    }

    @Override
    protected void releaseAction() {
        file = null;
        super.releaseAction();
    }

    @Override
    protected void doAction() throws Exception {
        Preconditions.checkNotNull(file);
        if (log.isInfoEnabled()) {
            log.info("Will export example species temporary " +
                     "referential to file: " + file);
        }

        TuttiReferentialImportExportService service =
                getContext().getTuttiReferentialImportExportService();

        service.exportTemporarySpeciesExample(file);
    }

    @Override
    public void postSuccessAction() {
        super.postSuccessAction();
        sendMessage(_("tutti.manageTemporaryReferential.action.chooseReferentialSpeciesFile.export.success", file));
    }
}

==> tutti-ui-swing-2.3-sources.jar: fr/ifremer/tutti/ui/swing/content/referential/ExportTemporarySpeciesExampleAction.java <==
package fr.ifremer.tutti.ui.swing.content.referential;

/*
 * #%L
 * Tutti :: UI
 * $Id: ExportTemporarySpeciesExampleAction.java 954 2013-05-16 16:00:37Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/referential/ExportTemporarySpeciesExampleAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Preconditions;
import fr.ifremer.tutti.TuttiIOUtil;
import fr.ifremer.tutti.service.referential.TuttiReferentialImportExportService;
import fr.ifremer.tutti.ui.swing.TuttiUIContext;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.io.File;

import static org.nuiton.i18n.I18n._;

/**
 * Export an example file of temporary species referential.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ExportTemporarySpeciesExampleAction extends AbstractTuttiAction<TuttiUIContext, ManageTemporaryReferentialUI, ManageTemporaryReferentialUIHandler> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ExportTemporarySpeciesExampleAction.class);

    private File file;

    public ExportTemporarySpeciesExampleAction(ManageTemporaryReferentialUIHandler handler) {
        super(handler, true);
    }

    @Override
    protected boolean prepareAction() throws Exception {

        boolean doAction = super.prepareAction();

        if (doAction) {

            // choose file to export
            file = TuttiUIUtil.saveFile(
                    "exportSpeciesExample.csv",
                    getContext().getMainUI(),
                    _("tutti.manageTemporaryReferential.title.choose.exportTemporarySpeciesExampleFile"),
                    _("tutti.manageTemporaryReferential.action.chooseReferentialSpeciesFile.export"),
                    "^.*\\.csv", _("tutti.common.file.csv")
            );
            if (file == null) {

                // user cancel
                doAction = false;
            } else {

                // add extension if missing
                file = TuttiIOUtil.addExtensionIfMissing(file, ".csv");

                // ask user to confirm overwrite.
                doAction = getHandler().askOverwriteFile(file);
            }
        }
        return doAction;
    }

    @Override
    protected void releaseAction() {
        file = null;
        super.releaseAction();
    }

    @Override
    protected void doAction() throws Exception {
        Preconditions.checkNotNull(file);
        if (log.isInfoEnabled()) {
            log.info("Will export example species temporary " +
                     "referential to file: " + file);
        }

        TuttiReferentialImportExportService service =
                getContext().getTuttiReferentialImportExportService();

        service.exportTemporarySpeciesExample(file);
    }

    @Override
    public void postSuccessAction() {
        super.postSuccessAction();
        sendMessage(_("tutti.manageTemporaryReferential.action.chooseReferentialSpeciesFile.export.success", file));
    }
}
